@@ -1,6 +1,6 @@
 from .containers import ImportContainer, ExportContainer
 from .errors import ModelClassNotRegistered
-from .policy import DISCARD_OBJECT, RelinkAction, BaseRelinkAction, ImportPolicy, ExportPolicy
+from .policy import DISCARD_OBJECT, ManyToManyImportAction, RelinkAction, BaseRelinkAction, ImportPolicy, ExportPolicy
 from .serializers import Exporter, ForeignKey, ReverseForeignKey, ManyToMany
 from .types import ID, Ref, Attachment, ObjectData, ContainerFormat
 
@@ -16,6 +16,7 @@ __all__ = [
     'ContainerFormat',
     'ImportPolicy',
     'ExportPolicy',
+    'ManyToManyImportAction',
 
     'Exporter',
     'ForeignKey',
